==> rheolef_6.5.orig.tar.gz: rheolef-6.5/doc/pexamples/level_set_sphere.sh <==
#!/bin/sh
#
# This file is part of Rheolef.
#
# Copyright (C) 2000-2009 Pierre Saramito 
#
# Rheolef is free software; you can redistribute it and/or modify
# it under the terms of the GNU General Public License as published by
# the Free Software Foundation; either version 2 of the License, or
# (at your option) any later version.
#
# Rheolef is distributed in the hope that it will be useful,
# but WITHOUT ANY WARRANTY; without even the implied warranty of
# MERCHANTABILITY or FITNESS FOR A PARTICULAR PURPOSE.  See the
# GNU General Public License for more details.
#
# You should have received a copy of the GNU General Public License
# along with Rheolef; if not, write to the Free Software
# Foundation, Inc., 59 Temple Place, Suite 330, Boston, MA  02111-1307  USA
#
# -------------------------------------------------------------------------
SRCDIR=${SRCDIR-"."}
TOP_SRCDIR=${TOP_SRCDIR-"../.."}
BINDIR="${TOP_SRCDIR}/nfem/pbin"
SBINDIR="${TOP_SRCDIR}/nfem/sbin"
GEODIR="${TOP_SRCDIR}/nfem/ptst"
ROUNDER="../../nfem/pbin/field - -field -round"
NPROC_MAX=${NPROC_MAX-"8"}
. "${TOP_SRCDIR}/config/loop_mpirun.sh"

status=0

run "${SBINDIR}/mkgeo_grid_2d -v4 20 -a -2 -b 2 -c -2 -d 2            2>/dev/null | ${BINDIR}/geo -upgrade - > mesh-2d-20.geo"
run "${SBINDIR}/mkgeo_grid_3d -v4 20 -a -2 -b 2 -c -2 -d 2 -f -2 -g 2 2>/dev/null | ${BINDIR}/geo -upgrade - > mesh-3d-20.geo"

loop_mpirun "./level_set_sphere mesh-2d-20.geo 2>/dev/null | $BINDIR/geo -upgrade - 2>/dev/null | \$RUN ./level_set_sphere_check 0.012 >/dev/null 2>/dev/null"
if test $? -ne 0; then status=1; fi

loop_mpirun "./level_set_sphere mesh-3d-20.geo 2>/dev/null | $BINDIR/geo -upgrade - 2>/dev/null | \$RUN ./level_set_sphere_check 0.13 >/dev/null 2>/dev/null"
if test $? -ne 0; then status=1; fi

loop_mpirun "./level_set_sphere mesh-3d-20.geo -tq 2>/dev/null | $BINDIR/geo -upgrade - 2>/dev/null | \$RUN ./level_set_sphere_check 0.13 >/dev/null 2>/dev/null"
if test $? -ne 0; then status=1; fi

run "rm -f mesh-2d-20.geo mesh-3d.geo"

exit $status

==> rheolef_6.6.orig.tar.gz: rheolef-6.6/doc/pexamples/level_set_sphere.sh <==
#!/bin/sh
#
# This file is part of Rheolef.
#
# Copyright (C) 2000-2009 Pierre Saramito 
#
# Rheolef is free software; you can redistribute it and/or modify
# it under the terms of the GNU General Public License as published by
# the Free Software Foundation; either version 2 of the License, or
# (at your option) any later version.
#
# Rheolef is distributed in the hope that it will be useful,
# but WITHOUT ANY WARRANTY; without even the implied warranty of
# MERCHANTABILITY or FITNESS FOR A PARTICULAR PURPOSE.  See the
# GNU General Public License for more details.
#
# You should have received a copy of the GNU General Public License
# along with Rheolef; if not, write to the Free Software
# Foundation, Inc., 59 Temple Place, Suite 330, Boston, MA  02111-1307  USA
#
# -------------------------------------------------------------------------
SRCDIR=${SRCDIR-"."}
TOP_SRCDIR=${TOP_SRCDIR-"../.."}
GEODIR="${TOP_SRCDIR}/nfem/ptst"
SBINDIR="../../nfem/sbin"
BINDIR="../../nfem/pbin"
ROUNDER="../../nfem/pbin/field - -field -round"
NPROC_MAX=${NPROC_MAX-"8"}
. "${TOP_SRCDIR}/config/loop_mpirun.sh"

status=0

run "${SBINDIR}/mkgeo_grid_2d -v4 20 -a -2 -b 2 -c -2 -d 2            2>/dev/null | ${BINDIR}/geo -upgrade - > mesh-2d-20.geo"
run "${SBINDIR}/mkgeo_grid_3d -v4 20 -a -2 -b 2 -c -2 -d 2 -f -2 -g 2 2>/dev/null | ${BINDIR}/geo -upgrade - > mesh-3d-20.geo"

loop_mpirun "./level_set_sphere mesh-2d-20.geo 2>/dev/null | $BINDIR/geo -upgrade - 2>/dev/null | \$RUN ./level_set_sphere_check 0.012 >/dev/null 2>/dev/null"
if test $? -ne 0; then status=1; fi

loop_mpirun "./level_set_sphere mesh-3d-20.geo 2>/dev/null | $BINDIR/geo -upgrade - 2>/dev/null | \$RUN ./level_set_sphere_check 0.13 >/dev/null 2>/dev/null"
if test $? -ne 0; then status=1; fi

loop_mpirun "./level_set_sphere mesh-3d-20.geo -tq 2>/dev/null | $BINDIR/geo -upgrade - 2>/dev/null | \$RUN ./level_set_sphere_check 0.13 >/dev/null 2>/dev/null"
if test $? -ne 0; then status=1; fi

run "rm -f mesh-2d-20.geo mesh-3d.geo"

exit $status
